==> atlassian-rest-common-7.2.0-sources.jar: com/atlassian/plugins/rest/common/error/jersey/UncaughtExceptionEntity.java <==
package com.atlassian.plugins.rest.common.error.jersey;

import java.io.PrintWriter;
import java.io.StringWriter;
import java.util.List;

import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.Request;
import javax.ws.rs.core.Response;
import javax.ws.rs.core.Variant;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;

import com.atlassian.plugins.rest.common.Status;

import static com.atlassian.plugins.rest.common.error.jersey.constants.UncaughtExceptionEntityConstants.ATLASSIAN_REST_RESPONSE_STACKTRACES;
import static com.atlassian.plugins.rest.common.error.jersey.constants.UncaughtExceptionEntityConstants.ATLASSIAN_REST_RESPONSE_STACKTRACES_ABSENT;
import static com.atlassian.plugins.rest.common.error.jersey.constants.UncaughtExceptionEntityConstants.ATLASSIAN_REST_RESPONSE_STACKTRACES_PRESENT;
import static com.atlassian.plugins.rest.common.error.jersey.constants.UncaughtExceptionEntityConstants.NO_STACKTRACE_MESSAGE;

/**
 * An analog of {@link Status} specifically for uncaught exceptions. The stack trace is
 * included.
 */
@XmlRootElement(name = "status")
public class UncaughtExceptionEntity {
    private static final Integer INTERNAL_SERVER_ERROR_CODE =
            Response.Status.INTERNAL_SERVER_ERROR.getStatusCode();
    /**
     * This is a redundant duplicate of the HTTP error code but it may be clearer in
     * a browser.
     */
    @XmlElement(name = "status-code")
    private final Integer code = INTERNAL_SERVER_ERROR_CODE;

    /**
     * A humane readable message for the given status.
     */
    @XmlElement
    private final String message;

    @XmlElement(name = "stack-trace")
    private final String stackTrace;

    /**
     * JAXB requires a default constructor.
     */
    public UncaughtExceptionEntity() {
        this.message = null;
        this.stackTrace = null;
    }

    public UncaughtExceptionEntity(Throwable t, String errorId) {
        this.message = t.getMessage();
        boolean shouldSeeStacktrace =
                System.getProperty(ATLASSIAN_REST_RESPONSE_STACKTRACES, ATLASSIAN_REST_RESPONSE_STACKTRACES_ABSENT)
                .equals(ATLASSIAN_REST_RESPONSE_STACKTRACES_PRESENT);
        if(shouldSeeStacktrace) {
            StringWriter sw = new StringWriter();
            PrintWriter pw = new PrintWriter(sw);
            t.printStackTrace(pw);
            this.stackTrace = sw.toString();
        } else {
            this.stackTrace = NO_STACKTRACE_MESSAGE + errorId;
        }
    }

    public String getMessage() {
        return message;
    }

    public String getStackTrace() {
        return stackTrace;
    }

    private static final MediaType TEXT_PLAIN_UTF8_TYPE = MediaType.valueOf("text/plain; charset=utf-8");

    /**
     * These are the media types that an UncaughtExceptionEntity can be represented as.
     */
    private static final List<Variant> POSSIBLE_VARIANTS = Variant.mediaTypes(
            MediaType.APPLICATION_XML_TYPE,
            MediaType.APPLICATION_JSON_TYPE,
            MediaType.TEXT_PLAIN_TYPE).add().build();

    public static MediaType variantFor(Request request) {
        Variant v = request.selectVariant(POSSIBLE_VARIANTS);
        if (v == null) {
            v = POSSIBLE_VARIANTS.get(0);
        }

        /* If we include the charset in the variant then it gets prioritised as a default. Select
         * it as text/plain and then switch in the variant with the charset here.
         */
        MediaType t = v.getMediaType();

        if (t.equals(MediaType.TEXT_PLAIN_TYPE)) {
            return TEXT_PLAIN_UTF8_TYPE;
        } else {
            return t;
        }
    }

    @Override
    public String toString() {
        return "code=" + code +
                ", message='" + message + '\'' +
                ", stackTrace='" + stackTrace;
    }
}

==> atlassian-rest-common-8.0.8-sources.jar: com/atlassian/plugins/rest/common/error/jersey/UncaughtExceptionEntity.java <==
package com.atlassian.plugins.rest.common.error.jersey;

import java.io.PrintWriter;
import java.io.StringWriter;
import java.util.List;
import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.Request;
import javax.ws.rs.core.Response;
import javax.ws.rs.core.Variant;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;

import com.atlassian.plugins.rest.common.Status;

import static com.atlassian.plugins.rest.common.error.jersey.constants.UncaughtExceptionEntityConstants.ATLASSIAN_REST_RESPONSE_STACKTRACES;
import static com.atlassian.plugins.rest.common.error.jersey.constants.UncaughtExceptionEntityConstants.ATLASSIAN_REST_RESPONSE_STACKTRACES_ABSENT;
import static com.atlassian.plugins.rest.common.error.jersey.constants.UncaughtExceptionEntityConstants.ATLASSIAN_REST_RESPONSE_STACKTRACES_PRESENT;
import static com.atlassian.plugins.rest.common.error.jersey.constants.UncaughtExceptionEntityConstants.NO_STACKTRACE_MESSAGE;

/**
 * An analog of {@link Status} specifically for uncaught exceptions. The stack trace is
 * included.
 */
@XmlRootElement(name = "status")
public class UncaughtExceptionEntity {
    private static final Integer INTERNAL_SERVER_ERROR_CODE = Response.Status.INTERNAL_SERVER_ERROR.getStatusCode();
    /**
     * This is a redundant duplicate of the HTTP error code but it may be clearer in
     * a browser.
     */
    @XmlElement(name = "status-code")
    private final Integer code = INTERNAL_SERVER_ERROR_CODE;

    /**
     * A humane readable message for the given status.
     */
    @XmlElement
    private final String message;

    @XmlElement(name = "stack-trace")
    private final String stackTrace;

    /**
     * JAXB requires a default constructor.
     */
    public UncaughtExceptionEntity() {
        this.message = null;
        this.stackTrace = null;
    }

    public UncaughtExceptionEntity(Throwable t, String errorId) {
        this.message = t.getMessage();
        boolean shouldSeeStacktrace = System.getProperty(
                        ATLASSIAN_REST_RESPONSE_STACKTRACES, ATLASSIAN_REST_RESPONSE_STACKTRACES_ABSENT)
                .equals(ATLASSIAN_REST_RESPONSE_STACKTRACES_PRESENT);
        if (shouldSeeStacktrace) {
            StringWriter sw = new StringWriter();
            PrintWriter pw = new PrintWriter(sw);
            t.printStackTrace(pw);
            this.stackTrace = sw.toString();
        } else {
            this.stackTrace = NO_STACKTRACE_MESSAGE + errorId;
        }
    }

    public String getMessage() {
        return message;
    }

    public String getStackTrace() {
        return stackTrace;
    }

    private static final MediaType TEXT_PLAIN_UTF8_TYPE = MediaType.valueOf("text/plain; charset=utf-8");

    /**
     * These are the media types that an UncaughtExceptionEntity can be represented as.
     */
    private static final List<Variant> POSSIBLE_VARIANTS = Variant.mediaTypes(
                    MediaType.APPLICATION_XML_TYPE, MediaType.APPLICATION_JSON_TYPE, MediaType.TEXT_PLAIN_TYPE)
            .add()
            .build();

    public static MediaType variantFor(Request request) {
        Variant v = request.selectVariant(POSSIBLE_VARIANTS);
        if (v == null) {
            v = POSSIBLE_VARIANTS.get(0);
        }

        /* If we include the charset in the variant then it gets prioritised as a default. Select
         * it as text/plain and then switch in the variant with the charset here.
         */
        MediaType t = v.getMediaType();

        if (t.equals(MediaType.TEXT_PLAIN_TYPE)) {
            return TEXT_PLAIN_UTF8_TYPE;
        } else {
            return t;
        }
    }

    @Override
    public String toString() {
        return "code=" + code + ", message='" + message + '\'' + ", stackTrace='" + stackTrace;
    }
}
